# Field Collection To Paragraphs migration

Provides a way to migrate Drupal 8+ sites using Field Collection fields to equivalent Paragraphs fields.

A database backup is always recommended before running any migrations.

**NOTE:** The migration doesn't delete the existing `field_collection` fields from their attached entities as that's something you'll want to do manually.

### Instructions

#### Global migration configuration options

Global configuration options are available inside the `migrate_plus.migration_group.field_collection_to_paragraphs` config under the `shared_configuration/source` property.

- `field_collection_types`: An array of Field Collection types to migrate to Paragraphs.
- `field_collection_type_mapping`: A mapping for Field Collection bundle names to Paragraph ones.
- `field_collection_field_name_mapping` - A mapping for Field Collection field names to their destination names when attached to a parent entity (node/taxonomy term).

By default, the module attempts to migrate all the Field Collections in your site to Paragraphs.
You can restrict the migration to specific ones by specifying a collection mapping in the `migrate_plus.migration_group.field_collection_to_paragraphs:field_collection_types` config.

#### Running the migration

You might want to review the migration config following its installation and a config export, make any changes to the config and import back.

You'll want to run the `field_collection_to_paragraph_parent_node` and `field_collection_to_paragraph_parent_taxonomy_term` migrations as normal.

This can be done from the migration admin menu (`/admin/structure/migrate/manage/field_collection_to_paragraphs/migrations`) or using Drush.

##### Using Drush

Simply migrate all your existing field collections by running:

```bash
drush migrate-import field_collection_to_paragraph_parent_node,field_collection_to_paragraph_parent_taxonomy_term --execute-dependencies
```

Or run them step by step using:

```bash
# Create the paragraph types.
drush migrate-import field_collection_to_paragraph_type
# Create the paragraph item fields and display settings.
drush migrate-import field_collection_to_paragraph_field_storage
drush migrate-import field_collection_to_paragraph_field_instance
drush migrate-import field_collection_to_paragraph_field_entity_view
drush migrate-import field_collection_to_paragraph_field_entity_form_display
# Create relevant fields on the parent node/taxonomy terms.
drush migrate-import field_collection_to_paragraph_parent_field_storage
drush migrate-import field_collection_to_paragraph_parent_field_instance
# Create the equivalent paragraph items.
drush migrate-import field_collection_to_paragraph_item
# Create relevant display settings on the parent node/taxonomy terms.
drush migrate-import field_collection_to_paragraph_parent_field_entity_view
drush migrate-import field_collection_to_paragraph_parent_field_entity_form_display
# Attach the paragraphs to the parent node/taxonomy terms.
drush migrate-import field_collection_to_paragraph_parent_node
drush migrate-import field_collection_to_paragraph_parent_taxonomy_term
```
